API Reference
=============

This section provides detailed documentation for all Calibre classes and functions.

.. toctree::
   :maxdepth: 2

   calibrators
   metrics
   utils

Overview
--------

Calibre provides three main modules:

- :doc:`calibrators`: Calibration algorithms and base classes
- :doc:`metrics`: Evaluation metrics for calibration quality
- :doc:`utils`: Utility functions for data processing